@@ -15,8 +15,8 @@ from functools import wraps
 import asyncio
 from aiohttp import ClientSession
 
-
 logger = logging.getLogger(__name__)
+logger.setLevel(logging.INFO)
 
 all_versions = defaultdict(list) # a dict created with its values being list
 
@@ -98,13 +98,14 @@ def rm_tempfile():
 
     global TEMP_FILE
     if not TEMP_FILE:
-        logger.info("No tempfile found to be deleted.")
+        print("No tempfile found to be deleted.")
         return
 
     os.remove(TEMP_FILE)
     
     file_name = TEMP_FILE.split("/")[-1]
-    logger.info(f"{file_name} has been removed successfully.")
+    print(f"{file_name} has been removed successfully.")
+
     TEMP_FILE = ""     
 
 def get_browser(browser):
@@ -173,7 +174,7 @@ def get_input():
 
     try:
         if args.version:
-            print("fake_user_agent " + settings.__version__)
+            print("fake_user_agent " + settings.version)
             sys.exit()
 
         if args.remove:
@@ -182,7 +183,7 @@ def get_input():
 
         if args.debug:
             logger.setLevel(logging.DEBUG)
-
+            
         browser = args.browser
 
         if args.nocache:
@@ -193,8 +194,6 @@ def get_input():
     except KeyboardInterrupt:
         print("\nStopped by user.")
 
- 
-@timer
 def user_agent(browser=None, use_tempfile=True):
     """Entry point for getting a user agent by importing this function in a python script."""
 
@@ -203,16 +202,19 @@ def user_agent(browser=None, use_tempfile=True):
 
 if __name__ == "__main__":
     import settings
+    import log
     from errors import FakeUserAgentError
     from parse import parse_args
 
     TEMP_FILE = settings.TEMP_FILE
+    get_input()
+   
 
 else:
     from . import settings
+    from . import log
     from .errors import FakeUserAgentError
     from .parse import parse_args
 
     TEMP_FILE = settings.TEMP_FILE
 
-get_input()
