@@ -5,9 +5,9 @@ import re
 import tempfile
 import logging
 
-import log
+from . import log
 
-version = "2.0.0" 
+version = "2.0.1" 
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
